﻿using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9477
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;

            map.TrackOverlay.TrackMode = TrackMode.Rectangle;
            map.TrackOverlay.TrackEnded += TrackOverlay_TrackEnded;
            map.TrackOverlay.TrackStarting += TrackOverlay_TrackStarting;

            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\AppData\states.shp");
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = WorldStreetsAreaStyles.Forest();
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(shapeFileLayer);
            map.Overlays.Add("mdboverlay", layerOverlay);

            shapeFileLayer.Open();
            map.CurrentExtent = shapeFileLayer.GetBoundingBox();
            map.Refresh();
        }

        private void TrackOverlay_TrackStarting(object sender, TrackStartingTrackInteractiveOverlayEventArgs e)
        {
            map.TrackOverlay.TrackShapeLayer.InternalFeatures.Clear();
        }

        private void TrackOverlay_TrackEnded(object sender, TrackEndedTrackInteractiveOverlayEventArgs e)
        {
            foreach (FeatureLayer layer in (map.Overlays["mdboverlay"] as LayerOverlay).Layers) //loop through the layers in the overlay holding the personalgeodatabasefeaturelayers
            {
                if (layer.IsVisible) //only check the ones that are currently visible
                {
                    layer.Open();

                    var features = layer.QueryTools.GetFeaturesWithin(e.TrackShape, ReturningColumnsType.AllColumns); //ERROR THROWN HERE //get the features within the rectangle shape I drew
                    layer.Close();
                }
            }
        }
    }
}
